@@ -171,33 +171,6 @@ class YamlParser(object):
             break
 
     def gen_xml(self, xml, data):
-        XML.SubElement(xml, 'actions')
-        description = XML.SubElement(xml, 'description')
-        description.text = data.get('description', '')
-        XML.SubElement(xml, 'keepDependencies').text = 'false'
-        if data.get('disabled'):
-            XML.SubElement(xml, 'disabled').text = 'true'
-        else:
-            XML.SubElement(xml, 'disabled').text = 'false'
-        if data.get('block-downstream'):
-            XML.SubElement(xml,
-                    'blockBuildWhenDownstreamBuilding').text = 'true'
-        else:
-            XML.SubElement(xml,
-                    'blockBuildWhenDownstreamBuilding').text = 'false'
-        if data.get('block-upstream'):
-            XML.SubElement(xml,
-                    'blockBuildWhenUpstreamBuilding').text = 'true'
-        else:
-            XML.SubElement(xml,
-                    'blockBuildWhenUpstreamBuilding').text = 'false'
-        if data.get('concurrent'):
-            XML.SubElement(xml, 'concurrentBuild').text = 'true'
-        else:
-            XML.SubElement(xml, 'concurrentBuild').text = 'false'
-        if('quiet-period' in data):
-            XML.SubElement(xml, 'quietPeriod').text = str(data['quiet-period'])
-
         for module in self.registry.modules:
             if hasattr(module, 'gen_xml'):
                 module.gen_xml(self, xml, data)
@@ -246,7 +219,8 @@ class XmlJob(object):
 
 class CacheStorage(object):
     def __init__(self):
-        self.cachefilename = os.path.expanduser('~/.jenkins_jobs_cache.yml')
+        cache_dir = self.get_cache_dir()
+        self.cachefilename = os.path.join(cache_dir, 'jenkins_jobs_cache.yml')
         try:
             yfile = file(self.cachefilename, 'r')
         except IOError:
@@ -255,6 +229,18 @@ class CacheStorage(object):
         self.data = yaml.load(yfile)
         yfile.close()
 
+    @staticmethod
+    def get_cache_dir():
+        home = os.path.expanduser('~')
+        if home == '~':
+            raise OSError('Could not locate home folder')
+        xdg_cache_home = os.environ.get('XDG_CACHE_HOME') or \
+            os.path.join(home, '.cache')
+        path = os.path.join(xdg_cache_home, 'jenkins_jobs')
+        if not os.path.isdir(path):
+            os.makedirs(path)
+        return path
+
     def set(self, job, md5):
         self.data[job] = md5
         yfile = file(self.cachefilename, 'w')
@@ -301,7 +287,7 @@ class Jenkins(object):
 
 class Builder(object):
     def __init__(self, jenkins_url, jenkins_user, jenkins_password,
-                      config=None):
+                 config=None):
         self.jenkins = Jenkins(jenkins_url, jenkins_user, jenkins_password)
         self.cache = CacheStorage()
         self.global_config = config
