@@ -45,7 +45,10 @@ def git(self, xml_parent, data):
 
     :arg str url: URL of the git repository
     :arg str refspec: refspec to fetch
+    :arg str name: name to fetch
     :arg list(str) branches: list of branch specifiers to build
+    :arg str basedir: location relative to the workspace root to clone to
+             (default: workspace)
     :arg bool skip-tag: Skip tagging
     :arg bool prune: Prune remote branches
     :arg bool clean: Clean after checkout
@@ -54,7 +57,21 @@ def git(self, xml_parent, data):
     :arg bool recursive-submodules: Recursively update submodules
     :arg bool use-author: Use author rather than committer in Jenkin's build
       changeset
+    :arg str git-tool: The name of the Git installation to use
     :arg bool wipe-workspace: Wipe out workspace before build
+    :arg str browser: what repository browser to use (default '(Auto)')
+    :arg str browser-url: url for the repository browser
+
+    :browser values:
+        :githubweb:
+        :fisheye:
+        :bitbucketweb:
+        :gitblit:
+        :gitlab:
+        :gitoriousweb:
+        :gitweb:
+        :redmineweb:
+        :viewgit:
 
     Example::
 
@@ -64,6 +81,8 @@ def git(self, xml_parent, data):
           branches:
             - master
             - stable
+          browser: githubweb
+          browser-url: http://github.com/foo/example.git
     """
 
     # XXX somebody should write the docs for those with option name =
@@ -80,9 +99,9 @@ def git(self, xml_parent, data):
         ("fastpoll", 'remotePoll', False),
         (None, 'buildChooser', '', {
             'class': 'hudson.plugins.git.util.DefaultBuildChooser'}),
-        (None, 'gitTool', "Default"),
+        ("git-tool", 'gitTool', "Default"),
         (None, 'submoduleCfg', '', {'class': 'list'}),
-        (None, 'relativeTargetDir', ''),
+        ('basedir', 'relativeTargetDir', ''),
         (None, 'reference', ''),
         (None, 'excludedRegions', ''),
         (None, 'excludedUsers', ''),
@@ -90,14 +109,14 @@ def git(self, xml_parent, data):
         (None, 'gitConfigEmail', ''),
         ('skip-tag', 'skipTag', False),
         (None, 'scmName', ''),
-        ]
+    ]
 
     scm = XML.SubElement(xml_parent,
                          'scm', {'class': 'hudson.plugins.git.GitSCM'})
     XML.SubElement(scm, 'configVersion').text = '2'
     user = XML.SubElement(scm, 'userRemoteConfigs')
     huser = XML.SubElement(user, 'hudson.plugins.git.UserRemoteConfig')
-    XML.SubElement(huser, 'name').text = 'origin'
+    XML.SubElement(huser, 'name').text = data.get('name', 'origin')
     if 'refspec' in data:
         refspec = data['refspec']
     else:
@@ -121,6 +140,28 @@ def git(self, xml_parent, data):
             xe.text = str(val).lower()
         else:
             xe.text = val
+    browser = data.get('browser', 'auto')
+    browserdict = {'githubweb': 'GithubWeb',
+                   'fisheye': 'FisheyeGitRepositoryBrowser',
+                   'bitbucketweb': 'BitbucketWeb',
+                   'cgit': 'CGit',
+                   'gitblit': 'GitBlitRepositoryBrowser',
+                   'gitlab': 'GitLab',
+                   'gitoriousweb': 'GitoriousWeb',
+                   'gitweb': 'GitWeb',
+                   'redmineweb': 'RedmineWeb',
+                   'viewgit': 'ViewGitWeb',
+                   'auto': 'auto'}
+    if browser not in browserdict:
+        raise Exception("Browser entered is not valid must be one of: " +
+                        "githubweb, fisheye, bitbucketweb, cgit, gitblit, " +
+                        "gitlab, gitoriousweb, gitweb, redmineweb, viewgit, " +
+                        "or auto")
+    if browser != 'auto':
+        bc = XML.SubElement(scm, 'browser', {'class':
+                            'hudson.plugins.git.browser.' +
+                            browserdict[browser]})
+        XML.SubElement(bc, 'url').text = data['browser-url']
 
 
 def svn(self, xml_parent, data):
@@ -156,18 +197,18 @@ def svn(self, xml_parent, data):
                basedir: repo2
     """
     scm = XML.SubElement(xml_parent, 'scm', {'class':
-              'hudson.scm.SubversionSCM'})
+                         'hudson.scm.SubversionSCM'})
     locations = XML.SubElement(scm, 'locations')
     if 'repos' in data:
         repos = data['repos']
         for repo in repos:
             module = XML.SubElement(locations,
-              'hudson.scm.SubversionSCM_-ModuleLocation')
+                                    'hudson.scm.SubversionSCM_-ModuleLocation')
             XML.SubElement(module, 'remote').text = repo['url']
             XML.SubElement(module, 'local').text = repo.get('basedir', '.')
     elif 'url' in data:
         module = XML.SubElement(locations,
-           'hudson.scm.SubversionSCM_-ModuleLocation')
+                                'hudson.scm.SubversionSCM_-ModuleLocation')
         XML.SubElement(module, 'remote').text = data['url']
         XML.SubElement(module, 'local').text = data.get('basedir', '.')
     else:
@@ -182,7 +223,7 @@ def svn(self, xml_parent, data):
     elif updater == 'update':
         updaterclass = 'UpdateUpdater'
     XML.SubElement(scm, 'workspaceUpdater', {'class':
-                'hudson.scm.subversion.' + updaterclass})
+                   'hudson.scm.subversion.' + updaterclass})
 
 
 class SCM(jenkins_jobs.modules.base.Base):
